package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Feb 22, 2026
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ErrorResponse struct {
Error string `json:"error"`
Message string `json:"message"`
}
type LoginRequest struct {
Username string `json:"username" validate:"required"`
Password string `json:"password" validate:"required"`
}
type RefreshRequest struct {
RefreshToken string `json:"refreshToken" validate:"required"`
}
type TokenPair struct {
AccessToken string `json:"accessToken"`
RefreshToken string `json:"refreshToken"`
ExpiresAt int64 `json:"expiresAt"`
}
type UserResponse struct {
ID int64 `json:"id"`
Username string `json:"username"`
Firstname string `json:"firstname"`
Lastname string `json:"lastname"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.